MysqlConn

Struct MysqlConn 

pub struct MysqlConn(pub Conn);
A wrapper around mysql_async::Conn that implements sql_composer::driver::ComposerConnectionAsync.

Dereferences to the inner mysql_async::Conn, so all native async methods are available directly.

Tuple Fields

0: Conn

Implementations

Source

impl MysqlConn

pub fn from_conn(conn: Conn) -> Self

Wrap an existing mysql_async::Conn.

Methods from Deref<Target = Conn>

pub fn id(&self) -> u32

Returns connection identifier.

pub fn last_insert_id(&self) -> Option<u64>

Returns the ID generated by a query (usually INSERT) on a table with a column having the AUTO_INCREMENT attribute. Returns None if there was no previous query on the connection or if the query did not update an AUTO_INCREMENT value.

pub fn affected_rows(&self) -> u64

Returns the number of rows affected by the last INSERT, UPDATE, REPLACE or DELETE query.

pub fn info(&self) -> Cow<'_, str>

Text information, as reported by the server in the last OK packet, or an empty string.

pub fn get_warnings(&self) -> u16

Number of warnings, as reported by the server in the last OK packet, or 0.

pub fn last_ok_packet(&self) -> Option<&OkPacket<'static>>

Returns a reference to the last OK packet.

pub fn reset_connection(&mut self, reset_connection: bool)

Turns on/off automatic connection reset (see crate::PoolOpts::with_reset_connection).

Only makes sense for pooled connections.

pub fn server_version(&self) -> (u16, u16, u16)

Returns server version.

pub fn opts(&self) -> &Opts

Returns connection options.

pub fn set_infile_handler<T>(&mut self, handler: T)
where T: Future<Output = Result<Pin<Box<dyn Stream<Item = Result<Bytes, Error>> + Send>>, Error>> + Send + Sync + 'static,

Setup local LOCAL INFILE handler (see “LOCAL INFILE Handlers” section of the crate-level docs).

It’ll overwrite existing local handler, if any.

pub async fn reset(&mut self) -> Result<bool, Error>

Executes COM_RESET_CONNECTION.

Returns false if command is not supported (requires MySql >5.7.2, MariaDb >10.2.3). For older versions consider using Conn::change_user.

pub async fn change_user(&mut self, opts: ChangeUserOpts) -> Result<(), Error>

Executes COM_CHANGE_USER.

This might be used as an older and slower alternative to COM_RESET_CONNECTION that works on MySql prior to 5.7.3 (MariaDb prior ot 10.2.4).

Note
  • Using non-default opts for a pooled connection is discouraging.
  • Connection options will be permanently updated.
pub async fn start_transaction( &mut self, options: TxOpts, ) -> Result<Transaction<'_>, Error>

Starts a transaction.