MysqlConnection

Struct MysqlConnection 

pub struct MysqlConnection(pub Conn);
A wrapper around mysql::Conn that implements sql_composer::driver::ComposerConnection.

Dereferences to the inner mysql::Conn, so all native sync methods are available directly.

Tuple Fields

0: Conn

Implementations

Source

impl MysqlConnection

pub fn from_conn(conn: Conn) -> Self

Wrap an existing mysql::Conn.

Methods from Deref<Target = Conn>

pub fn server_version(&self) -> (u16, u16, u16)

Returns version number reported by the server.

pub fn connection_id(&self) -> u32

Returns connection identifier.

pub fn affected_rows(&self) -> u64

Returns number of rows affected by the last query.

pub fn last_insert_id(&self) -> u64

Returns last insert id of the last query.

Returns zero if there was no last insert id.

pub fn warnings(&self) -> u16

Returns number of warnings, reported by the server.

pub fn info_ref(&self) -> &[u8]

Info, reported by the server.

Will be empty if not defined.

pub fn info_str(&self) -> Cow<'_, str>

Info, reported by the server.

Will be empty if not defined.

pub fn session_state_changes(&self) -> Result<Vec<SessionStateInfo<'_>>, Error>

pub fn reset(&mut self) -> Result<(), Error>

Tries to reset the connection.

This function will try to invoke COM_RESET_CONNECTION with a fall back to COM_CHANGE_USER on older servers.

Warning

There is a long-standing bug in mysql 5.6 that kills this functionality in presence of connection attributes (see Bug #92954).

Note

Re-executes Opts::get_init.

pub fn change_user(&mut self, opts: ChangeUserOpts) -> Result<(), Error>

Executes COM_CHANGE_USER.

This might be used as an older and slower alternative to COM_RESET_CONNECTION that works on MySql prior to 5.7.3 (MariaDb prior ot 10.2.4).

Note
  • Using non-default opts for a pooled connection is discouraging.
  • Connection options will be updated permanently.
Warning

There is a long-standing bug in mysql 5.6 that kills this functionality in presence of connection attributes (see Bug #92954).

pub fn ping(&mut self) -> Result<(), Error>

Executes COM_PING on Conn. Return true on success or false on error.

pub fn select_db(&mut self, schema: &str) -> Result<(), Error>

Executes COM_INIT_DB on Conn.

pub fn start_transaction( &mut self, tx_opts: TxOpts, ) -> Result<Transaction<'_>, Error>

Starts new transaction with provided options. readonly is only available since MySQL 5.6.5.

pub fn set_local_infile_handler(&mut self, handler: Option<LocalInfileHandler>)

Sets a callback to handle requests for local files. These are caused by using LOAD DATA LOCAL INFILE queries. The callback is passed the filename, and a Writeable object to receive the contents of that file. Specifying None will reset the handler to the one specified in the Opts for this connection.

pub fn no_backslash_escape(&self) -> bool